API docs for “spamfighter.core.test.test_partner.PartnerAuthorizerTestCase”

# Class s.c.t.t.PartnerAuthorizerTestCase(unittest.TestCase):

Part of spamfighter.core.test.test_partner View Source View In Hierarchy

Тест на предоставление механизма авторизации по умолчанию.

Method | testDefaultPartnerAuthorizer | Undocumented
Method | testPartnerAuthorizer | Undocumented

def testDefaultPartnerAuthorizer(self): (source)
Undocumented
def testPartnerAuthorizer(self): (source)
Undocumented